@@ -8,24 +8,22 @@ import (
 
 // Config contains all information to schedule a profile command
 type Config struct {
-	ProfileName             string
-	CommandName             string // restic command
-	Schedules               []string
-	Permission              string
-	WorkingDirectory        string
-	Command                 string // path to resticprofile executable
-	Arguments               CommandArguments
-	Environment             []string
-	JobDescription          string
-	TimerDescription        string
-	Priority                string // Priority is either "background" or "standard"
-	ConfigFile              string
-	Flags                   map[string]string // flags added to the command line
-	IgnoreOnBattery         bool
-	IgnoreOnBatteryLessThan int
-	AfterNetworkOnline      bool
-	SystemdDropInFiles      []string
-	removeOnly              bool
+	ProfileName        string
+	CommandName        string // restic command
+	Schedules          []string
+	Permission         string
+	WorkingDirectory   string
+	Command            string // path to resticprofile executable
+	Arguments          CommandArguments
+	Environment        []string
+	JobDescription     string
+	TimerDescription   string
+	Priority           string // Priority is either "background" or "standard"
+	ConfigFile         string
+	Flags              map[string]string // flags added to the command line
+	AfterNetworkOnline bool
+	SystemdDropInFiles []string
+	removeOnly         bool
 }
 
 // NewRemoveOnlyConfig creates a job config that may be used to call Job.Remove() on a scheduled job
@@ -48,9 +46,9 @@ func (s *Config) SetCommand(wd, command string, args []string) {
 // Priority is either "background" or "standard"
 func (s *Config) GetPriority() string {
 	s.Priority = strings.ToLower(s.Priority)
-	// default value for priority is "background"
+	// default value for priority is "standard"
 	if s.Priority != constants.SchedulePriorityBackground && s.Priority != constants.SchedulePriorityStandard {
-		s.Priority = constants.SchedulePriorityBackground
+		s.Priority = constants.SchedulePriorityStandard
 	}
 	return s.Priority
 }
